# Shares 1.10.0 Patch Level 6
**Operating Systems:** Windows

**Date:** 12/19/2024

## Table of Contents
1. [Patch Level 6 Fixes](#patch-level-6-fixes)
2. [Patch Level 5 Fixes](#patch-level-5-fixes)
3. [Patch Level 4 Fixes](#patch-level-4-fixes)
4. [Patch Level 3 Fixes](#patch-level-3-fixes)
5. [Patch Level 2 Fixes](#patch-level-2-fixes)
6. [Patch Level 1 Fixes](#patch-level-1-fixes)
7. [Known Issues](#known-issues)
8. [Patch Instructions](#patch-instructions)
9. [Connect Shares to MySQL 8](#connect-shares-to-mysql-8)

This patch includes the following fixes:

### Patch Level 6 Fixes
| Issue | Description                                                                                                    |
| ---------- |:--------------------------------------------------------------------------------------------------------- |
| AS-423     | Support for Aspera Connect 4                                                                              |

### Patch Level 5 Fixes
| Issue | Description                                                                                                    |
| ---------- |:--------------------------------------------------------------------------------------------------------- |
| AS-328     | Provide a workaround to connect Shares to MySQL 8.                                                        |

### Patch Level 4 Fixes
| Issue | Description                                                                                                    |
| ---------- |:--------------------------------------------------------------------------------------------------------- |
| AS-404     | Upgraded Nginx, OpenSSL, and PCRE * Zlib to the latest compatible versions.                               |


### Patch Level 3 Fixes
| Issue | Description                                                                                                    |
| ---------- |:--------------------------------------------------------------------------------------------------------- |
| AS-256     | User's login sessions remain active even after password reset.                                            |

### Patch Level 2 Fixes
| Issue | Description                                                                                                    |
| ---------- |:--------------------------------------------------------------------------------------------------------- |
| AS-308     | Upgraded JRE to version `1.8.0_392` |

### Patch Level 1 Fixes
| Issue | Description                                                                                                    |
| ---------- |:--------------------------------------------------------------------------------------------------------- |
| AS-531     | Upgraded JQuery-UI to version 1.13.2 |

### Known issues
| Jira Issue | Description                                                                                     |
| ---------- | ----------------------------------------------------------------------------------------------- |
| AS-360     | Unable to edit user status.                                                                     |
| AS-414     | Users are able to login after resetting their password in multiple sessions.                    |

## Patch instructions

### Applying the patch for Windows systems:

1. Download and extract the patch file (`IBM_Aspera_Shares_1.10.0_Linux_Patch_Level_6.zip`).

2. Back up all the files in the  (`C:\Shares`) folder.

3. Stop all Shares services with patch files:

    a. Go to **Control Panel > Administrative Tools > Services**.
    
    b. Right click each 'IBM Aspera' service and select **Stop**.
    
4. Replace existing files with patch files:

    a. Replace existing files by copying folders from `src` patch files to the appropriate directories in the Shares folder (`C:\Shares\www`).

    b. Delete the folder `C:\Shares\statscollector\jre`

    c. Replace existing files by copying `lib\jre` patch files to the appropriate directories in the Shares folder (`C:\Shares\statscollector\`).

5. Upgrade Nginx, Zlib, OpenSSL & PCRE to latest compatable versions
    a. Copy the contents of `lib\upgrades\*` to `c:/shares/nginx`
    b. _Optional_ : You can delete the objs folder `(c:/shares/nginx/objs)`

6. Remove the previous version of JQuery-UI: (`C:\Shares\www\public\javascripts\third-party\jquery-ui-1.12.1`)**(Optional)**

7. Restart all Shares services:

    a. Go to **Control Panel > Administrative Tools > Services**.

    b. Right click each 'IBM Aspera' service and select **Start**

8. Run the script to update the database table:

  ```
   cd > cd C:\shares\www
   bundle exec rake db:migrate
  ```

## Connect Shares to MySQL 8

Follow these steps to connect Shares with MySQL 8 database.
  1. Back up the current database: 

    ```
    cd C:\Program Files (x86)\Common Files\Aspera\Common\mysql\data\
    mysqldump -u username -p web_production > <path to the folder>/sharesdb.sql
    mysqldump -u username -p stats_collector > <path to the folder>/statscollectordb.sql
    ```
  
  2. MySQL 8 setup on a remote instnace

    a. Install MySQL 8 Database on a remote instance https://dev.mysql.com/downloads/installer/

    b. Create a User and Grant Permissions from mysql console
    
      ```
      CREATE USER 'root'@'<Shares Host IP>' IDENTIFIED WITH mysql_native_password BY '<MySQL pwd>';
      GRANT ALL PRIVILEGES on *.* TO 'root'@'<Shares host IP>' WITH GRANT OPTION;
      FLUSH PRIVILEGES;
      ```

    c. Create required databases
    
      ```
      create database web_production;
      create database stats_collector;
      ```

  3. Copy the backup files generated from  Step 1 to the remote MySQL8 database instance.

  4. Stop all the services:

    a. IBM Aspera Shares Nginx
  
    b. IBM Aspera Shares Delayed Job 1
  
    c. IBM Aspera Shares Web Services
  
    d. IBM Aspera Shares Stats Collector

  5. Update database details with the MySQL8 credentials (username, password, port, host):

    a. Update the Shares ```C:\Shares\www\config\database.yml``` file.

    b. Remove the ```C:\Shares\statscollector\lib``` and ```C:\Shares\statscollector\jre``` folder.

    c. Copy all the content from the new Stats Collector folder in the patch file to: ```C:\Shares\statscollector```.

    d. Update the Stats Collector ```C:\Shares\statscollector\etc\persistence.xml  ``` file.

    e. Run the batch script ```C:\Shares\statscollector\etc\RegUpdate.bat```
                
  6. Restore the remote database with the backup you created in step 1:
    ```
    mysql -u username -p web_production < sharesdb.sql
    mysql -u username -p stats_collector < statscollectordb.sql
    ```

  7. Restart all the services:
    a. IBM Aspera Shares Nginx
    b. IBM Aspera Shares Delayed Job 1
    c. IBM Aspera Shares Web Services
    d. IBM Aspera Shares Stats Collector
    
© IBM Aspera. Copyright IBM Corp. 2009, 2024  