class PreferencesController < ApplicationController

    before_filter :set_authorizable_user
  
    current_tab :level_1, :preferences
  
    def index
    end
  
    begin 'names'
      before_filter :set_names_changer, :only => [:names_edit, :names_update]
  
      def names_edit
        if @authorizable_user.local?
          render_js_replace
        end
      end
  
      def names_update
        if @authorizable_user.local?
          @names_changer.change(params)
        end
      end
  
      def set_names_changer
        @names_changer = Preferences::NamesChanger.new(@authorizable_user)
      end
      private :set_names_changer
    end
  
  
    begin 'email'
      before_filter :set_email_changer, :only => [:email_edit, :email_update]
  
      def email_edit
        if @authorizable_user.local?
          render_js_replace
        end
      end
  
      def email_update
        if @authorizable_user.local?
          @email_changer.change(params)
        end
      end
  
      def set_email_changer
        @email_changer = Preferences::EmailChanger.new(@authorizable_user)
      end
      private :set_email_changer
    end
  
    begin 'email settings'
      before_filter :set_email_settings_changer, :only => [:email_settings_edit, :email_settings_update]
  
      def email_settings_edit
        render_js_replace
      end
  
      def email_settings_update
        @email_settings_changer.change(params)
      end
  
      def set_email_settings_changer
        @email_settings_changer = Preferences::EmailSettingsChanger.new(@authorizable_user)
      end
      private :set_email_settings_changer
    end
  
    begin 'password change -- no authentication -- for initial reset or expired password'
      # Does NOT prompt for password since we are sent here immediately after logging in.
      password_no_auth_actions = [:password_edit, :password_update]
      skip_before_filter :redirect_to_license_if_invalid, :only => password_no_auth_actions
      skip_before_filter :logout_on_invalid_license, :only => password_no_auth_actions
      skip_before_filter :check_password_reset, :only => password_no_auth_actions
      before_filter :set_password_changer, :only => password_no_auth_actions
      before_filter :require_reset, :only => password_no_auth_actions
  
      def password_edit
      end
  
      def password_update
        if @password_changer.change(params)
          reset_session
          flash[:notice] = "Password changed"
          redirect_to_login(local: true)
        else
          flash.now[:error] = @password_changer.error_message
          render :action => 'password_edit'
        end
      end
  
      def require_reset
        redirect_to root_path unless current_user.password_reset_required?
      end
      private :require_reset
  
      def set_password_changer
        @password_changer = Preferences::PasswordChanger.new(@authorizable_user)
      end
      private :set_password_changer
    end
  
    begin 'password change -- with authorization -- from user preferences'
      # prompts user for current password so unattended computer can't have
      # credentials changed.
      before_filter :set_password_changer_with_auth, :only => [:password_with_auth_edit, :password_with_auth_update]
  
      def password_with_auth_edit
        if @authorizable_user.local?
          render_js_replace
        end
      end
  
      def password_with_auth_update
        current_user_id = current_user.try(:authorizable_user).id
        if @authorizable_user.local?
          @password_changer_with_auth.change(params)
          ActiveRecord::SessionStore::Session.where(user_id: current_user_id).map(&:destroy) unless @password_changer_with_auth.error_message.present?
        end
      end
  
      def set_password_changer_with_auth
        @password_changer_with_auth = Preferences::PasswordChangerWithAuth.new(@authorizable_user)
      end
      private :set_password_changer_with_auth
    end
  
    begin 'display'
      before_filter :set_display_changer, :only => [:display_edit, :display_update]
  
      def display_edit
        render_js_replace
      end
  
      def display_update
        # because no time_zone_select_tag, had to get value from time_zone_select
        tz = params[:display_changer][:time_zone]
        @display_changer.change(params.merge(:time_zone => tz))
      end
  
      def set_display_changer
        @display_changer = Preferences::DisplayChanger.new(@authorizable_user)
      end
      private :set_display_changer
    end
  
    begin 'Connect Install Dialog'
      before_filter :set_connect_changer, :only => [:connect_edit, :connect_update]
  
      def connect_edit
        render_js_replace
      end
  
      def connect_update
        @connect_changer.change(params)
      end
  
      def set_connect_changer
        @connect_changer = Preferences::ConnectChanger.new(@authorizable_user)
      end
      private :set_display_changer
    end
  
end